@@ -2,7 +2,7 @@
 
 package Beam::Wire;
 {
-  $Beam::Wire::VERSION = '0.013';
+  $Beam::Wire::VERSION = '0.014';
 }
 
 use strict;
@@ -17,6 +17,7 @@ use Data::DPath qw ( dpath );
 use File::Basename qw( dirname );
 use File::Spec::Functions qw( catfile );
 use MooX::Types::MooseLike::Base qw( :all );
+use List::MoreUtils qw( all );
 
 
 
@@ -59,14 +60,24 @@ has services => (
 );
 
 
+has meta_prefix => (
+    is      => 'ro',
+    isa     => Str,
+    default => sub { '$' },
+);
+
+
 sub get {
-    my ( $self, $name ) = @_;
+    my ( $self, $name, %override ) = @_;
     if ( $name =~ '/' ) {
         my ( $container_name, $service ) = split m{/}, $name, 2;
         my $container = $self->services->{$container_name} ||=
             $self->create_service( %{ $self->config->{$container_name} } )
         ;
-        return $container->get( $service );
+        return $container->get( $service, %override );
+    }
+    if ( keys %override ) {
+        return $self->create_service( %override, extends => $name );
     }
     my $service = $self->services->{$name};
     if ( !$service ) {
@@ -156,25 +167,33 @@ sub merge_config {
 sub find_refs {
     my ( $self, @args ) = @_;
     my @out;
+    my $prefix = $self->meta_prefix;
+    my %meta = (
+        ref     => "${prefix}ref",
+        path    => "${prefix}path",
+        method  => "${prefix}method",
+        args    => "${prefix}args",
+    );
     for my $arg ( @args ) {
         if ( ref $arg eq 'HASH' ) {
             # detect references
             my @keys = keys %$arg;
-            if ( @keys and $keys[0] eq 'ref' ) {
+            if ( $arg->{ $meta{ref} } and all { /^\Q$prefix/ } @keys ) {
                 # resolve service ref
                 my @ref;
-                my $name = $arg->{ref};
+                my $name = $arg->{ $meta{ref} };
                 my $service = $self->get( $name );
                 # resolve service ref w/path
-                if ( $arg->{path} ) {
+                if ( my $path = $arg->{ $meta{path} } ) {
                     # locate foreign service data
                     my $conf = $self->config->{$name};
-                    @ref = dpath($arg->{path})->match($service);
+                    @ref = dpath( $path )->match($service);
                 }
-                elsif ( my $method = $arg->{method} ) {
-                    my @args = !$arg->{args}                ? ()
-                             : ref $arg->{args} eq 'ARRAY'  ? @{ $arg->{args} } 
-                             : $arg->{args};
+                elsif ( my $method = $arg->{ $meta{method} } ) {
+                    my $args = $arg->{ $meta{args} };
+                    my @args = !$args                ? ()
+                             : ref $args eq 'ARRAY'  ? @{ $args }
+                             : $args;
                     @ref = $service->$method( @args );
                 }
                 else {
@@ -211,7 +230,7 @@ Beam::Wire - A Dependency Injection Container
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -285,7 +304,7 @@ independently or as a dependent of other services.
         class: 'CHI'
         args:
             driver: 'DBI'
-            dbh: { ref: 'production_db' }
+            dbh: { $ref: 'production_db' }
     development_db:
         class: 'DBI'
         method: connect
@@ -296,7 +315,7 @@ independently or as a dependent of other services.
         class: 'CHI'
         args:
             driver: 'DBI'
-            dbh: { ref: 'development_db' }
+            dbh: { $ref: 'development_db' }
 
 =head3 Service Attributes
 
@@ -392,11 +411,11 @@ value, C<factory>, will create a new instance of the service every time:
     report_yesterday:
         class: My::Report
         args:
-            date: { ref: today, method: add, args: [ "days", "-1" ] }
+            date: { $ref: today, $method: add, $args: [ "days", "-1" ] }
     report_today:
         class: My::Report
         args:
-            date: { ref: today }
+            date: { $ref: today }
 
 C<DateTime->add> modifies the object and returns the newly-modified object (to
 allow for method chaining.) Without C<lifecycle: factory>, the C<today> service
@@ -469,14 +488,14 @@ container. If even more control is needed, you can make a subclass of Beam::Wire
         class: CHI
         args:
             driver: 'DBI'
-            dbh: { ref: 'dbh' }
+            dbh: { $ref: 'dbh' }
     dbh:
         class: DBI
         method: connect
         args:
-            - { ref: dsn }
-            - { ref: usr }
-            - { ref: pwd }
+            - { $ref: dsn }
+            - { $ref: usr }
+            - { $ref: pwd }
     dsn:
         value: "dbi:SQLite:memory:"
     usr:
@@ -487,8 +506,8 @@ container. If even more control is needed, you can make a subclass of Beam::Wire
 The reuse of service and configuration containers as arguments for other
 services is encouraged so we have provided a means of referencing those
 objects within your configuration. A reference is an arugment (a service
-argument) in the form of a hashref with a C<ref> key whose value is
-the name of another service. Optionally, this hashref may contain a C<path>
+argument) in the form of a hashref with a C<$ref> key whose value is
+the name of another service. Optionally, this hashref may contain a C<$path>
 key whose value is a L<Data::DPath> search string which should return the found
 data structure from within the referenced service.
 
@@ -519,11 +538,39 @@ loaded by L<Config::Any> using the file specified by the L<file> attribute.
 
 A hashref of services. If you have any services already built, add them here.
 
+=head2 meta_prefix
+
+The character that begins a meta-property inside of a service's C<args>. This
+includes C<$ref>, C<$path>, C<$method>, and etc...
+
+The default value is '$'. The empty string is allowed.
+
 =head1 METHODS
 
-=head2 get
+=head2 get( name, [ overrides ] )
 
-The get method resolves and returns the specified service.
+The get method resolves and returns the service named C<name>.
+
+C<overrides> may be a list of name-value pairs. If specified, get()
+will create an anonymous service that extends the C<name> service
+with the given config overrides:
+
+    # test.pl
+    use Beam::Wire;
+    my $wire = Beam::Wire->new(
+        config => {
+            foo => {
+                args => {
+                    text => 'Hello, World!',
+                },
+            },
+        },
+    );
+    my $foo = $wire->get( 'foo', args => { text => 'Hello, Chicago!' } );
+    print $foo; # prints "Hello, Chicago!"
+
+This allows you to create factories out of any service, overriding service
+configuration at run-time.
 
 =head2 set
 
